==> digikam_8.7.0.orig.tar.xz: digikam-8.7.0/core/utilities/geolocation/engine/plugins/runner/gpx/handlers/GPXcmtTagHandler.cpp <==
/* ============================================================
 *
 * This file is a part of digiKam project
 * https://www.digikam.org
 *
 * Date        : 2023-05-15
 * Description : geolocation engine based on Marble.
 *               (c) 2007-2022 Marble Team
 *               https://invent.kde.org/education/marble/-/raw/master/data/credits_authors.html
 *
 * SPDX-FileCopyrightText: 2023-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
 *
 * SPDX-License-Identifier: LGPL-2.1-or-later
 *
 * ============================================================ */

#include "GPXcmtTagHandler.h"

// Local includes

#include "GPXElementDictionary.h"
#include "GeoParser.h"
#include "GeoDataPlacemark.h"
#include "digikam_debug.h"

// type is used in wpt, rte and trk to provide some sort of keyword, like "Geocache/traditional cache",
// and in link to provide a mimetype

namespace Marble
{

namespace gpx
{

GPX_DEFINE_TAG_HANDLER(cmt)

GeoNode* GPXcmtTagHandler::parse(GeoParser& parser) const
{
    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1String(gpxTag_cmt)));

    GeoStackItem parentItem = parser.parentElement();

    if (parentItem.represents(gpxTag_wpt))
    {
        GeoDataPlacemark* placemark = parentItem.nodeAs<GeoDataPlacemark>();

        QString cmt = parser.readElementText().trimmed();

        if (!cmt.isEmpty())
        {
            QString desc = placemark->description();

            if (!desc.isEmpty())
            {
                desc += QLatin1String("<br/>");
            }

            placemark->setDescription(desc.append(cmt.replace(QLatin1Char('\n'), QLatin1String("\n<br/>"))));
            placemark->setDescriptionCDATA(true);
        }
    }

    return nullptr;
}

} // namespace gpx

} // namespace Marble

==> digikam_8.8.0.orig.tar.xz: digikam-8.8.0/core/utilities/geolocation/engine/plugins/runner/gpx/handlers/GPXcmtTagHandler.cpp <==
/* ============================================================
 *
 * This file is a part of digiKam project
 * https://www.digikam.org
 *
 * Date        : 2023-05-15
 * Description : geolocation engine based on Marble.
 *               (c) 2007-2022 Marble Team
 *               https://invent.kde.org/education/marble/-/raw/master/data/credits_authors.html
 *
 * SPDX-FileCopyrightText: 2023-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
 *
 * SPDX-License-Identifier: LGPL-2.1-or-later
 *
 * ============================================================ */

#include "GPXcmtTagHandler.h"

// Local includes

#include "GPXElementDictionary.h"
#include "GeoParser.h"
#include "GeoDataPlacemark.h"
#include "digikam_debug.h"

// type is used in wpt, rte and trk to provide some sort of keyword, like "Geocache/traditional cache",
// and in link to provide a mimetype

namespace Marble
{

namespace gpx
{

GPX_DEFINE_TAG_HANDLER(cmt)

GeoNode* GPXcmtTagHandler::parse(GeoParser& parser) const
{
    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1String(gpxTag_cmt)));

    GeoStackItem parentItem = parser.parentElement();

    if (parentItem.represents(gpxTag_wpt))
    {
        GeoDataPlacemark* placemark = parentItem.nodeAs<GeoDataPlacemark>();

        QString cmt = parser.readElementText().trimmed();

        if (!cmt.isEmpty())
        {
            QString desc = placemark->description();

            if (!desc.isEmpty())
            {
                desc += QLatin1String("<br>");
            }

            placemark->setDescription(desc.append(cmt.replace(QLatin1Char('\n'), QLatin1String("\n<br>"))));
            placemark->setDescriptionCDATA(true);
        }
    }

    return nullptr;
}

} // namespace gpx

} // namespace Marble
